@@ -127,6 +127,14 @@ void csch_line_update_bbox(csch_sheet_t *sheet, csch_line_t *line)
 	line->hdr.bbox.x2 = gb.p2.x; line->hdr.bbox.y2 = gb.p2.y;
 }
 
+void csch_line_center_bbox(csch_sheet_t *sheet, const csch_line_t *line, csch_rtree_box_t *dst)
+{
+	g2d_box_t gb = g2d_cline_bbox(&line->inst.c);
+
+	dst->x1 = gb.p1.x; dst->y1 = gb.p1.y;
+	dst->x2 = gb.p2.x; dst->y2 = gb.p2.y;
+}
+
 void csch_line_update(csch_sheet_t *sheet, csch_line_t *line, int do_xform)
 {
 	csch_cobj_update_pen(&line->hdr);
@@ -220,7 +228,7 @@ TODO("check end cap circle");
 static void line_move(csch_sheet_t *sheet, csch_chdr_t *obj, csch_coord_t dx, csch_coord_t dy, int undoable)
 {
 	csch_line_t *line = (csch_line_t *)obj;
-	csch_line_modify(sheet, line, &dx, &dy, &dx, &dy, undoable, 1);
+	csch_line_modify(sheet, line, &dx, &dy, &dx, &dy, undoable, 1, 0);
 
 	if ((line->hdr.parent != NULL) && (line->hdr.parent->role == CSCH_ROLE_WIRE_NET))
 		csch_wirenet_recalc_obj_conn(sheet, &line->hdr);
@@ -252,7 +260,7 @@ static void line_rotate(csch_sheet_t *sheet, csch_chdr_t *obj, csch_coord_t rcx,
 	csch_rotate_pt(&ncx1, &ncy1, rcx, rcy, cs, sn);
 	csch_rotate_pt(&ncx2, &ncy2, rcx, rcy, cs, sn);
 
-	csch_line_modify(sheet, line, &ncx1, &ncy1, &ncx2, &ncy2, undoable, 0);
+	csch_line_modify(sheet, line, &ncx1, &ncy1, &ncx2, &ncy2, undoable, 0, 0);
 }
 
 static void line_rotate90(csch_sheet_t *sheet, csch_chdr_t *obj, csch_coord_t rcx, csch_coord_t rcy, int n, int undoable)
@@ -264,7 +272,7 @@ static void line_rotate90(csch_sheet_t *sheet, csch_chdr_t *obj, csch_coord_t rc
 	csch_rotate90_pt(&ncx1, &ncy1, rcx, rcy, n);
 	csch_rotate90_pt(&ncx2, &ncy2, rcx, rcy, n);
 
-	csch_line_modify(sheet, line, &ncx1, &ncy1, &ncx2, &ncy2, undoable, 0);
+	csch_line_modify(sheet, line, &ncx1, &ncy1, &ncx2, &ncy2, undoable, 0, 0);
 }
 
 static void line_mirror(csch_sheet_t *sheet, csch_chdr_t *obj, csch_coord_t mcx, csch_coord_t mcy, int mirx, int miry, int undoable)
@@ -276,7 +284,7 @@ static void line_mirror(csch_sheet_t *sheet, csch_chdr_t *obj, csch_coord_t mcx,
 	csch_mirror_pt(&ncx1, &ncy1, mcx, mcy, mirx, miry);
 	csch_mirror_pt(&ncx2, &ncy2, mcx, mcy, mirx, miry);
 
-	csch_line_modify(sheet, line, &ncx1, &ncy1, &ncx2, &ncy2, undoable, 0);
+	csch_line_modify(sheet, line, &ncx1, &ncy1, &ncx2, &ncy2, undoable, 0, 0);
 }
 
 
@@ -286,7 +294,7 @@ static void line_inst2spec(csch_sheet_t *sheet, csch_chdr_t *obj, const csch_chd
 	csch_coord_t x1 = line->inst.c.p1.x, y1 = line->inst.c.p1.y;
 	csch_coord_t x2 = line->inst.c.p2.x, y2 = line->inst.c.p2.y;
 
-	csch_line_modify(sheet, (csch_line_t *)obj, &x1, &y1, &x2, &y2, undoable, 0);
+	csch_line_modify(sheet, (csch_line_t *)obj, &x1, &y1, &x2, &y2, undoable, 0, 0);
 }
 
 const csch_ops_t csch_ops_line = {
@@ -345,6 +353,7 @@ typedef struct {
 	csch_line_t *line; /* it is safe to save the object pointer because it is persistent (through the removed object list) */
 	g2d_cline_t spec;
 	unsigned disable_recalc:1;
+	unsigned recalc_conn_geo:1;
 } undo_line_modify_t;
 
 
@@ -358,6 +367,11 @@ static int undo_line_modify_swap(void *udata)
 	csch_line_update(u->line->hdr.sheet, u->line, 1);
 	if (!u->disable_recalc && (u->line->hdr.parent != NULL) && (u->line->hdr.parent->role == CSCH_ROLE_WIRE_NET))
 		csch_wirenet_recalc_line_chg(u->line->hdr.sheet, u->line);
+	if (u->recalc_conn_geo) {
+		long n;
+		for(n = 0; n < u->line->hdr.conn.used; n++)
+			csch_conn_auto_recalc_geo(u->line->hdr.sheet, u->line->hdr.conn.array[n]);
+	}
 	csch_sheet_set_changed(u->line->hdr.sheet, 1);
 
 	csch_cobj_redraw(u->line);
@@ -380,24 +394,58 @@ static const uundo_oper_t undo_line_modify = {
 	undo_line_modify_print
 };
 
+RND_INLINE void line_modify_endp(g2d_xform_t imx, csch_cgrp_t *parent, g2d_vect_t *dst_spec, g2d_vect_t *spec, g2d_vect_t *inst, csch_coord_t *x, csch_coord_t *y, int relative, int invxform)
+{
+	g2d_vect_t t;
 
-void csch_line_modify(csch_sheet_t *sheet, csch_line_t *line, csch_coord_t *x1, csch_coord_t *y1, csch_coord_t *x2, csch_coord_t *y2, int undoable, int relative)
+	if ((x == NULL) && (y == NULL)) {
+		/* cheap */
+		dst_spec->x = spec->x;
+		dst_spec->y = spec->y;
+	}
+
+	if (relative) {
+		t.x = (x == NULL) ? 0 : *x;
+		t.y = (y == NULL) ? 0 : *y;
+		if (invxform) {
+			t.x += parent->xform.x;
+			t.y += parent->xform.y;
+			t = g2d_xform_vect2vect(imx, t);
+		}
+		dst_spec->x = spec->x + t.x;
+		dst_spec->y = spec->y + t.y;
+	}
+	else {
+		t.x = (x == NULL) ? spec->x : *x;
+		t.y = (y == NULL) ? spec->y : *y;
+		if (invxform)
+			t = g2d_xform_vect2vect(imx, t);
+		dst_spec->x = t.x;
+		dst_spec->y = t.y;
+	}
+}
+
+void csch_line_modify(csch_sheet_t *sheet, csch_line_t *line, csch_coord_t *x1, csch_coord_t *y1, csch_coord_t *x2, csch_coord_t *y2, int undoable, int relative, int invxform)
 {
 	undo_line_modify_t utmp, *u = &utmp;
+	g2d_xform_t imx;
 
 	if (undoable) u = uundo_append(&sheet->undo, &undo_line_modify, sizeof(undo_line_modify_t));
 
 	u->line = line;
 	u->spec = line->spec; /* copy all fields */
-	u->spec.p1.x = (x1 == NULL) ? line->spec.p1.x : (relative ? (line->spec.p1.x + *x1) : *x1);
-	u->spec.p1.y = (y1 == NULL) ? line->spec.p1.y : (relative ? (line->spec.p1.y + *y1) : *y1);
-	u->spec.p2.x = (x2 == NULL) ? line->spec.p2.x : (relative ? (line->spec.p2.x + *x2) : *x2);
-	u->spec.p2.y = (y2 == NULL) ? line->spec.p2.y : (relative ? (line->spec.p2.y + *y2) : *y2);
+
+	if (invxform)
+		csch_cgrp_inverse_matrix(&imx, line->hdr.parent);
+
+	line_modify_endp(imx, line->hdr.parent, &u->spec.p1, &line->spec.p1, &line->inst.c.p1, x1, y1, relative, invxform);
+	line_modify_endp(imx, line->hdr.parent, &u->spec.p2, &line->spec.p2, &line->inst.c.p2, x2, y2, relative, invxform);
 
 	u->disable_recalc = 0;
+	u->recalc_conn_geo = 0;
 	undo_line_modify_swap(u);
+	u->recalc_conn_geo = 1; /* undo should recalc coord geo */
 	u->disable_recalc = 1; /* undo shouldn't have side effects */
 
 	if (undoable) csch_undo_inc_serial(sheet);
 }
-
