@@ -175,6 +175,8 @@ void csch_pen_free(csch_cpen_t *pen)
 	/* remove cached pens from any object and pen from group */
 	csch_pen_invalidate(pen, 1, 1, 1);
 
+	free(pen->font_family);
+	free(pen->font_style);
 	csch_cobj_uninit(&pen->hdr);
 	free(pen);
 }
