@@ -85,6 +85,21 @@ csch_text_t *csch_text_alloc(csch_sheet_t *sheet, csch_cgrp_t *parent, csch_oid_
 	return text;
 }
 
+/* Mirror and return rot_deg as mirx and miry directs */
+RND_INLINE double text_mirror_rot(const csch_text_t *text, double rot_deg, int mirx, int miry)
+{
+	double rot, sx, sy;
+
+	if ((mirx == 0) && (miry == 0))
+		return rot_deg;
+
+	rot = rot_deg / RND_RAD_TO_DEG;
+	sx = cos(rot); sy = sin(rot);
+	if (mirx) sx = -sx;
+	if (miry) sy = -sy;
+	return atan2(sy, sx) * RND_RAD_TO_DEG;
+}
+
 csch_text_t *csch_text_dup(csch_sheet_t *sheet, csch_cgrp_t *parent, const csch_text_t *src, int keep_id, int inst2spec)
 {
 	csch_text_t *dst = csch_text_alloc(sheet, parent, CSCH_KEEP_OID(parent, src->hdr.oid));
@@ -99,10 +114,18 @@ csch_text_t *csch_text_dup(csch_sheet_t *sheet, csch_cgrp_t *parent, const csch_
 	if (inst2spec) {
 		g2d_xform_t mx;
 		g2d_vect_t v1 = src->inst1, v2 = src->inst2;
+		double ir;
 
 		csch_cgrp_inverse_matrix(&mx, parent);
 
-		dst->spec_rot = src->inst_rot - parent->xform.rot;
+		/* undo the effect of text rotation on mirror;
+		   Test the original bug: revert back to r7977, use
+		   /work/manual_test/power.rs, select the right side circuit, drag&drop move
+		   it one grid point to the right -> when using src->inst_rot instead of
+		   ir, floater changes rotation by 180 deg */
+		ir = text_mirror_rot(src, src->inst_rot, src->inst_mirx, src->inst_miry);
+
+		dst->spec_rot = ir - parent->xform.rot;
 		dst->spec_mirx = src->inst_mirx ^ parent->xform.mirx;
 		dst->spec_miry = src->inst_miry ^ parent->xform.miry;
 
@@ -110,6 +133,7 @@ csch_text_t *csch_text_dup(csch_sheet_t *sheet, csch_cgrp_t *parent, const csch_
 		v2 = g2d_xform_vect2vect(mx, v2);
 		dst->spec1 = v1;
 		dst->spec2 = v2;
+		csch_chdr_copy_meta4dup(&dst->hdr, &src->hdr); /* have to happen before update because of rtree (display layer change in this call) */
 		csch_text_update(sheet, dst, 1);
 	}
 	else {
@@ -123,10 +147,10 @@ csch_text_t *csch_text_dup(csch_sheet_t *sheet, csch_cgrp_t *parent, const csch_
 		dst->inst_raw_rot = src->inst_raw_rot;
 		dst->inst_mirx = src->inst_mirx;
 		dst->inst_miry = src->inst_miry;
+
+		csch_chdr_copy_meta4dup(&dst->hdr, &src->hdr);
 	}
 
-
-	csch_chdr_copy_meta4dup(&dst->hdr, &src->hdr);
 	return dst;
 }
 
@@ -191,21 +215,6 @@ csch_text_t *csch_text_get(csch_sheet_t *sheet, csch_cgrp_t *grp, csch_oid_t oid
 	return text;
 }
 
-/* Mirror and return rot_deg as mirx and miry directs */
-csch_inline double text_mirror_rot(csch_text_t *text, double rot_deg, int mirx, int miry)
-{
-	double rot, sx, sy;
-
-	if ((mirx == 0) && (miry == 0))
-		return rot_deg;
-
-	rot = rot_deg / RND_RAD_TO_DEG;
-	sx = cos(rot); sy = sin(rot);
-	if (mirx) sx = -sx;
-	if (miry) sy = -sy;
-	return atan2(sy, sx) * RND_RAD_TO_DEG;
-}
-
 void csch_text_update_xform(csch_sheet_t *sheet, csch_text_t *text)
 {
 	if (text->hdr.parent != NULL) {
@@ -267,42 +276,42 @@ void csch_text_update(csch_sheet_t *sheet, csch_text_t *text, int do_xform)
 		csch_cobj_redraw_unfreeze(sheet);
 	}
 
-	text->spec15.x = text->spec2.x; text->spec15.y = text->spec1.y;
-	text->spec25.x = text->spec1.x; text->spec25.y = text->spec2.y;
+	if (do_xform) {
+		text->spec15.x = text->spec2.x; text->spec15.y = text->spec1.y;
+		text->spec25.x = text->spec1.x; text->spec25.y = text->spec2.y;
 
-	/* initial values of instance is copy of spec... */
-	text->inst1  = text->spec1;
-	text->inst2  = text->spec2;
-	text->inst15 = text->spec15;
-	text->inst25 = text->spec25;
-	text->inst_rot = text->spec_rot;
-	text->inst_raw_rot = text->spec_rot;
-	text->inst_mirx = text->spec_mirx;
-	text->inst_miry = text->spec_miry;
+		/* initial values of instance is copy of spec... */
+		text->inst1  = text->spec1;
+		text->inst2  = text->spec2;
+		text->inst15 = text->spec15;
+		text->inst25 = text->spec25;
+		text->inst_rot = text->spec_rot;
+		text->inst_raw_rot = text->spec_rot;
+		text->inst_mirx = text->spec_mirx;
+		text->inst_miry = text->spec_miry;
 
-	if (text->spec_mirx || text->spec_miry) {
-		csch_mirror_pt(&text->inst2.x, &text->inst2.y, text->inst1.x, text->inst1.y, text->spec_mirx, text->spec_miry);
-		csch_mirror_pt(&text->inst15.x, &text->inst15.y, text->inst1.x, text->inst1.y, text->spec_mirx, text->spec_miry);
-		csch_mirror_pt(&text->inst25.x, &text->inst25.y, text->inst1.x, text->inst1.y, text->spec_mirx, text->spec_miry);
-	}
+		if (text->spec_mirx || text->spec_miry) {
+			csch_mirror_pt(&text->inst2.x, &text->inst2.y, text->inst1.x, text->inst1.y, text->spec_mirx, text->spec_miry);
+			csch_mirror_pt(&text->inst15.x, &text->inst15.y, text->inst1.x, text->inst1.y, text->spec_mirx, text->spec_miry);
+			csch_mirror_pt(&text->inst25.x, &text->inst25.y, text->inst1.x, text->inst1.y, text->spec_mirx, text->spec_miry);
+		}
 
-	/* ... then add local text rotation keeping x1;y1 in place */
-	if (text->inst_rot != 0) {
-		double cs, sn, rot = -fmod(text->inst_rot, 360.0) / RND_RAD_TO_DEG;
+		/* ... then add local text rotation keeping x1;y1 in place */
+		if (text->inst_rot != 0) {
+			double cs, sn, rot = -fmod(text->inst_rot, 360.0) / RND_RAD_TO_DEG;
 
-		if (text->spec_mirx ^ text->spec_miry)
-			rot = -rot;
+			if (text->spec_mirx ^ text->spec_miry)
+				rot = -rot;
 
-		cs = cos(rot); sn = sin(rot);
-		csch_rotate_pt(&text->inst2.x, &text->inst2.y, text->inst1.x, text->inst1.y, cs, sn);
-		csch_rotate_pt(&text->inst15.x, &text->inst15.y, text->inst1.x, text->inst1.y, cs, sn);
-		csch_rotate_pt(&text->inst25.x, &text->inst25.y, text->inst1.x, text->inst1.y, cs, sn);
-	}
+			cs = cos(rot); sn = sin(rot);
+			csch_rotate_pt(&text->inst2.x, &text->inst2.y, text->inst1.x, text->inst1.y, cs, sn);
+			csch_rotate_pt(&text->inst15.x, &text->inst15.y, text->inst1.x, text->inst1.y, cs, sn);
+			csch_rotate_pt(&text->inst25.x, &text->inst25.y, text->inst1.x, text->inst1.y, cs, sn);
+		}
 
-	/* ... and then parent transformation */
-	if (do_xform)
+		/* ... and then parent transformation */
 		csch_text_update_xform(sheet, text);
-
+	}
 
 	csch_text_update_bbox(sheet, text);
 
