@@ -33,13 +33,13 @@
 #include <librnd/core/rnd_printf.h>
 #include <librnd/core/conf.h>
 #include <librnd/core/compat_misc.h>
+#include <librnd/core/compat_fs.h>
 
 #include "abstract.h"
 #include "cnc_text.h"
 #include "cnc_grp.h"
 #include "cnc_text_dyn.h"
 #include "project.h"
-#include "util_path.h"
 
 RND_INLINE const csch_chdr_t *get_attrib_obj(char **path, const csch_text_t *text)
 {
@@ -74,7 +74,7 @@ static const char *prj_name(const char *fullpath)
 	static char res[1024], *d;
 	const char *s;
 
-	for(s = csch_parent_dir_name(fullpath), d = res; *s != '/'; s++, d++) {
+	for(s = rnd_parent_dir_name(fullpath), d = res; *s != '/'; s++, d++) {
 		if ((d - res) > sizeof(res)-2)
 			break;
 		*d = *s;
