@@ -41,14 +41,14 @@ int csch_compile_project(csch_project_t *prj, int viewid, csch_abstract_t *dst,
 
 /* Compile attribute src of cgrp into dst. If dstkey is NULL, srca's
    key is used. src is used for history and is always freed.
-   Err1 and err2 are two strings printed in error messages
+   Err1, err2 and err3 are three strings printed in error messages
    for location, with space in between. If referee is 1, src is a group
    ref. If append is 1, append src array to dst array (fails if either
    src or dst attrib is not an array). If append is 0, but src key starts
    with '+', append is set to 1 internally. If dsta_out is not NULL,
    destination attribute (abstract model) is returned there.
    Returns 0 on success. */
-int csch_compile_attribute(csch_ahdr_t *dst, const char *dstkey, const csch_attrib_t *srca, csch_source_arg_t *src, const char *err1, const char *err2, int referee, int append, csch_attrib_t **dsta_out);
+int csch_compile_attribute(csch_ahdr_t *dst, const char *dstkey, const csch_attrib_t *srca, csch_source_arg_t *src, const char *err1, const char *err2, const char *err3, int referee, int append, csch_attrib_t **dsta_out);
 
 
 /* For compiler hooks in plugins */
