@@ -46,9 +46,12 @@ enum {
 	CSCH_EVENT_PRJ_COMPILED,                     /* [d] called after the project has been compiled (abstract model changed); no args (project can be retrieved from hidlib -> sheet) */
 	CSCH_EVENT_PRJ_VIEWS_CHANGED,                /* [d] called after project view configuration changed; no args (project can be retrieved from hidlib -> sheet) */
 	CSCH_EVENT_PRJ_VIEW_ACTIVATED,               /* [d] called after a new view is set active in a project (project can be retrieved from hidlib -> sheet) */
+	CSCH_EVENT_PRJ_STANCE_CHANGED,               /* [d] called after any project stance changed */
 	CSCH_EVENT_LIBRARY_CHANGED,                  /* [d] called after a new entry is added to the library so that any open library window can be updated on the GUI; no args (sheet can be retrieved from hidlib) */
 	CSCH_EVENT_SELECTION_CHANGED,                /* [d] called after object selection changed (sleected/unselected objects) */
 
+	CSCH_EVENT_DRC_RUN,                          /* [d] called from core to run all configured DRCs (implemented in plugins). Args: (csch_drc_t *ctx). Each DRC plugin shall increase ctx->ran if it did any check */
+
 	/* generated by the app, not libcschem */
 	CSCH_EVENT_BUFFER_COPY_CUSTOM,               /* [d] called before an object is duplicated from sheet to buffer; args: (csch_chdr_t **obj, csch_sheet_t *buffer); *obj is the current object, initially the source object on the sheet; destination buffer the second arg */
 	CSCH_EVENT_BUFFER_PASTE_CUSTOM,              /* [d] called before an object is duplicated from buffer to sheet; args: (csch_chdr_t **obj); *obj is the current object, initially the source object in the buffer; destination sheet is in the hidlib arg */
