@@ -2,7 +2,7 @@
  *                            COPYRIGHT
  *
  *  cschem - modular/flexible schematics editor - libcschem (core library)
- *  Copyright (C) 2020,2022 Tibor 'Igor2' Palinkas
+ *  Copyright (C) 2020,2022,2024 Tibor 'Igor2' Palinkas
  *
  *  (Supported by NLnet NGI0 PET Fund in 2022)
  *
@@ -104,6 +104,9 @@ RND_INLINE csch_chdr_t *csch_cnc_remove_(csch_sheet_t *sheet, csch_chdr_t *obj,
 	if (how & CSCH_REM_UNDOABLE)
 		csch_conn_auto_recalc(sheet, obj);
 
+	if ((parent != NULL) && (parent->role == CSCH_ROLE_WIRE_NET))
+		csch_wirenet_post_remove_checks(sheet, parent, (how & CSCH_REM_UNDOABLE));
+
 	if ((how & CSCH_REM_DEL_EMPTY_PARENT) && (parent != NULL) && (parent->id2obj.used == 0) && (!csch_obj_is_deleted(&parent->hdr)))
 		csch_cnc_remove_(sheet, &parent->hdr, how);
 
