@@ -177,7 +177,7 @@ int csch_lib_add(csch_sheet_t *sheet, csch_lib_master_t *master, char *path, int
 			free(path); path = NULL;
 			return 0;
 		}
-		rnd_message(RND_MSG_ERROR, "Symbol library mapping error: no plugin to handle '%s' (or plugin failed to map it, e.g. path does not exist)\n", path);
+		rnd_message(RND_MSG_ERROR, "%s library mapping error: no plugin to handle '%s' (or plugin failed to map it, e.g. path does not exist)\n", master->name, path);
 		free(path); path = NULL;
 		return -1;
 	}
@@ -194,7 +194,7 @@ int csch_lib_add(csch_sheet_t *sheet, csch_lib_master_t *master, char *path, int
 			abort(); /* at the moment this shouldn't happen */
 #if 0
 			if (real_path != path) free(real_path);
-			rnd_message(RND_MSG_ERROR, "Symbol library mapping error: %s failed to map '%s'\n", be_new->name, path);
+			rnd_message(RND_MSG_ERROR, "%s library mapping error: %s failed to map '%s'\n", master->name, be_new->name, path);
 			free(path); path = NULL;
 			return -1;
 #endif
@@ -203,17 +203,17 @@ int csch_lib_add(csch_sheet_t *sheet, csch_lib_master_t *master, char *path, int
 	}
 	else { /* matching real_path: reuse */
 		TODO("TODO#41: sharing root pointers may not be a good idea: they will not have unique names; see the other TODO#41");
+		if (real_path != path) free(real_path);
 		free(path); path = NULL;/* we are going to use the existing one in root */
 		if (root->backend != be_new) {
-			if (real_path != path) free(real_path);
 			if (optional)
 				return 0;
-			rnd_message(RND_MSG_ERROR, "Symbol library mapping error: different plugins claim to handle '%s'\n", root->name);
+			rnd_message(RND_MSG_ERROR, "%s library mapping error: different plugins claim to handle '%s'\n", master->name, root->name);
 			return -1;
 		}
 		if (do_rehash) {
 			if (csch_lib_rehash(sheet, master, root) != 0) {
-				rnd_message(RND_MSG_ERROR, "Symbol library mapping error: failed to re-scan library '%s'\n", root->name);
+				rnd_message(RND_MSG_ERROR, "%s library mapping error: failed to re-scan library '%s'\n", master->name, root->name);
 				root->just_mapped = 1;
 			}
 			else
@@ -324,10 +324,22 @@ int csch_lib_add_local(csch_sheet_t *sheet, csch_lib_master_t *master)
 	return 0;
 }
 
+/* Replace orig_root with new_root in a sheet's lib */
+static void lib_rehash_update_root_in_all_sheets(csch_sheet_t *sheet, csch_lib_master_t *master, csch_lib_t *orig_root, csch_lib_t *new_root)
+{
+	long n;
+	csch_lib_root_t *libroot = sheet->libs.array[master->uid];
+
+	assert(libroot != NULL);  /* csch_lib_add() created it */
+	for(n = 0; n < libroot->roots.used; n++)
+		if (libroot->roots.array[n] == orig_root)
+			libroot->roots.array[n] = new_root;
+}
+
 int csch_lib_rehash(csch_sheet_t *sheet, csch_lib_master_t *master, csch_lib_t *node)
 {
-	csch_lib_root_t *libroot;
 	csch_lib_t *root = node, *orig_root, *new_root;
+	rnd_design_t *dsg;
 	long n;
 
 	while(root->parent != NULL) root = root->parent;
@@ -352,13 +364,11 @@ int csch_lib_rehash(csch_sheet_t *sheet, csch_lib_master_t *master, csch_lib_t *
 	assert(new_root != NULL); /* csch_lib_add() created it */
 
 	TODO("TODO#41: sharing root pointers may not be a good idea: they will not have unique names; see the other TODO#41");
-	/* have to fix up aliases */
-	libroot = sheet->libs.array[master->uid];
-	assert(libroot != NULL);  /* csch_lib_add() created it */
-	for(n = 0; n < libroot->roots.used; n++) {
-		if (libroot->roots.array[n] == orig_root)
-			libroot->roots.array[n] = new_root;
-	}
+
+	/* have to fix up aliases - in all open sheets because of shared roots! */
+	for(dsg = gdl_first(&rnd_designs); dsg != NULL; dsg = dsg->link.next)
+		lib_rehash_update_root_in_all_sheets((csch_sheet_t *)dsg, master, orig_root, new_root);
+
 	csch_lib_free(orig_root);
 	return 0;
 }
@@ -376,6 +386,7 @@ void csch_lib_add_all(csch_sheet_t *sheet, csch_lib_master_t *master, const rnd_
 			csch_lib_t *root = htsp_get(&master->roots, real_path);
 			if (root != NULL)
 				root->just_mapped = 0;
+			free(real_path);
 		}
 	}
 
@@ -482,6 +493,7 @@ void csch_plug_library_init(void)
 {
 	htsp_init(&lib_masters, strhash, strkeyeq);
 	csch_lib_get_master("symbol", 1);
+	csch_lib_get_master("hlibrary", 1);
 
 	/* backends is all-zero already */
 }
