@@ -76,6 +76,21 @@ void sch_rnd_backann_update(sch_rnd_backann_t *ctx)
 	backann_data2dlg(ctx);
 }
 
+static void backann_init_dlgs(void)
+{
+	if (!sch_rnd_prj2backann_inited) {
+		htpp_init(&sch_rnd_prj2backann, ptrhash, ptrkeyeq);
+		sch_rnd_prj2backann_inited = 1;
+	}
+}
+
+void sch_rnd_backann_present(sch_rnd_backann_t *pctx)
+{
+	backann_init_dlgs();
+	sch_rnd_backann_check(pctx);
+	backann_dlg(pctx);
+	htpp_set(&sch_rnd_prj2backann, (csch_project_t *)pctx->sheet->hidlib.project, pctx);
+}
 
 static const char csch_acts_Backann[] = "Backann([filename])\n";
 static const char csch_acth_Backann[] = "Load a back annotation file for interactive back annotation";
@@ -84,10 +99,7 @@ static fgw_error_t csch_act_Backann(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	rnd_design_t *hidlib = RND_ACT_DESIGN;
 	sch_rnd_backann_t ctx = {0}, *pctx;
 
-	if (!sch_rnd_prj2backann_inited) {
-		htpp_init(&sch_rnd_prj2backann, ptrhash, ptrkeyeq);
-		sch_rnd_prj2backann_inited = 1;
-	}
+	backann_init_dlgs();
 
 	ctx.sheet = (csch_sheet_t *)hidlib;
 	RND_ACT_MAY_CONVARG(1, FGW_STR, Backann, ctx.fn = argv[1].val.str);
@@ -132,9 +144,7 @@ static fgw_error_t csch_act_Backann(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	pctx = malloc(sizeof(sch_rnd_backann_t));
 	memcpy(pctx, &ctx, sizeof(sch_rnd_backann_t));
 
-	sch_rnd_backann_check(pctx);
-	backann_dlg(pctx);
-	htpp_set(&sch_rnd_prj2backann, (csch_project_t *)ctx.sheet->hidlib.project, pctx);
+	sch_rnd_backann_present(pctx);
 
 	RND_ACT_IRES(0);
 	return 0;
