@@ -49,6 +49,21 @@ conf_bom_t conf_bom;
 typedef csch_acomp_t bom_obj_t;
 #include "../../src_3rd/rnd_inclib/lib_bom/lib_bom.h"
 
+static const char *bom_name_prefix(bom_subst_ctx_t *ctx)
+{
+	static char tmp[256]; /* this is safe: caller will make a copy right after we return */
+	char *o = tmp;
+	const char *t;
+	int n = 0;
+
+	TODO("this breaks in hierarchic case: S1/S2/U2 returns S instead of U, see example 32_subtree");
+
+	for(t = ctx->name; isalpha(*t) && (n < sizeof(tmp)-1); t++,n++,o++)
+		*o = *t;
+	*o = '\0';
+	return tmp;
+}
+
 static const char *subst_user(bom_subst_ctx_t *ctx, const char *key)
 {
 	if (strncmp(key, "sym.", 4) == 0) {
@@ -56,23 +71,33 @@ static const char *subst_user(bom_subst_ctx_t *ctx, const char *key)
 
 		if (strncmp(key, "a.", 2) == 0) return csch_attrib_get_str(&ctx->obj->hdr.attr, key+2);
 		else if (strcmp(key, "name") == 0) return ctx->name;
-		if (strcmp(key, "prefix") == 0) {
-			static char tmp[256]; /* this is safe: caller will make a copy right after we return */
-			char *o = tmp;
-			const char *t;
-			int n = 0;
-
-			for(t = ctx->name; isalpha(*t) && (n < sizeof(tmp)-1); t++,n++,o++)
-				*o = *t;
-			*o = '\0';
-			return tmp;
-		}
+		if (strcmp(key, "prefix") == 0) return bom_name_prefix(ctx);
 	}
 
 	return NULL;
 }
 
 
+static void part_rnd_print(bom_subst_ctx_t *ctx, bom_obj_t *obj_, const char *name)
+{
+	if (name == NULL) {
+		return; /* no globals */
+	}
+	else {
+		csch_acomp_t *obj = (csch_acomp_t *)obj_;
+		htsp_entry_t *e;
+
+		bom_tdx_fprint_safe_kv(ctx->f, "sym.name", name);
+		bom_tdx_fprint_safe_kv(ctx->f, "sym.prefix", bom_name_prefix(ctx));
+
+		/* print all scalar attributes */
+		for(e = htsp_first(&obj->hdr.attr); e != NULL; e = htsp_next(&obj->hdr.attr, e)) {
+			csch_attrib_t *a = e->value;
+			bom_tdx_fprint_safe_kkv(ctx->f, "sym.a.", a->key, a->val);
+		}
+	}
+}
+
 static csch_plug_io_t ebom;
 
 static int bom_export_prio(const char *fn, const char *fmt, csch_plug_io_type_t type)
