@@ -42,9 +42,13 @@ static rnd_export_opt_t bom_options[] = {
 	 RND_HATT_ENUM, 0, 0, {0, 0, 0}, NULL},
 #define HA_format 1
 
+	{"part-rnd", "export a part-rnd tEDAx that contains the selected template and all data",
+	 RND_HATT_BOOL, 0, 0, {0, 0, 0}, NULL},
+#define HA_part_rnd 2
+
 	{"view", "Name of the view to export (use first view when not specified)",
 	 RND_HATT_STRING, 0, 0, {0, 0, 0}, 0},
-#define HA_view 2
+#define HA_view 3
 };
 
 #define NUM_OPTIONS (sizeof(bom_options)/sizeof(bom_options[0]))
@@ -91,6 +95,8 @@ static void bom_do_export(rnd_hid_t *hid, rnd_design_t *design, rnd_hid_attr_val
 		}
 	}
 
+	bom_part_rnd_mode = options[HA_part_rnd].lng ? part_rnd_print : NULL;
+
 	sch_rnd_export_prj_abst((csch_project_t *)sheet->hidlib.project, sheet, viewid, "bom", options[HA_outfile].str, options);
 }
 
