@@ -142,17 +142,23 @@ static int svg_do_export_sheet(rnd_hid_t *hid, rnd_design_t *dsg, rnd_hid_attr_v
 {
 	rnd_xform_t xform = {0};
 	FILE *f = NULL;
+	int do_close = 0;
 
-	out_filename = cschem_export_filename(dsg, options[HA_svgfile].str, NULL, appspec->fn_page_suffix, ".svg");
+	if (strcmp(options[HA_svgfile].str, "/dev/stdout") != 0) {
+		out_filename = cschem_export_filename(dsg, options[HA_svgfile].str, NULL, appspec->fn_page_suffix, ".svg");
 
-	f = rnd_fopen_askovr(dsg, out_filename, "wb", ovr);
-	if (f == NULL) {
-		int ern = errno;
-		rnd_message(RND_MSG_ERROR, "svg_do_export(): failed to open %s: %s\n", out_filename, strerror(ern));
+		f = rnd_fopen_askovr(dsg, out_filename, "wb", ovr);
+		if (f == NULL) {
+			int ern = errno;
+			rnd_message(RND_MSG_ERROR, "svg_do_export(): failed to open %s: %s\n", out_filename, strerror(ern));
+			free(out_filename);
+			return -1;
+		}
 		free(out_filename);
-		return -1;
+		do_close = 1;
 	}
-	free(out_filename);
+	else
+		f = stdout;
 
 	rnd_svg_init(pctx, dsg, f, options[HA_opacity].lng, 1, options[HA_true_size].lng);
 	if (f != NULL)
@@ -165,7 +171,8 @@ static int svg_do_export_sheet(rnd_hid_t *hid, rnd_design_t *dsg, rnd_hid_attr_v
 
 	if (pctx->outf != NULL) {
 		rnd_svg_footer(pctx);
-		fclose(pctx->outf);
+		if (do_close)
+			fclose(pctx->outf);
 	}
 	pctx->outf = NULL;
 	rnd_svg_uninit(pctx);
