@@ -36,6 +36,7 @@
 #include <libcschem/plug_io.h>
 
 #include <plugins/lib_netlist_exp/lib_netlist_exp.h>
+#include <plugins/lib_tedax/write.h>
 
 static csch_plug_io_t etdx_net;
 
@@ -50,36 +51,17 @@ static int tdx_export_prio(const char *fn, const char *fmt, csch_plug_io_type_t
 	return 0;
 }
 
-static void tdx_fprint_escape(FILE *f, const char *val)
-{
-	if ((val == NULL) || (*val == '\0')) {
-		fputc('-', f);
-		return;
-	}
-	for(; *val != '\0'; val++) {
-		switch(*val) {
-			case '\\': fputc('\\', f); fputc('\\', f); break;
-			case '\n': fputc('\\', f); fputc('n', f); break;
-			case '\r': fputc('\\', f); fputc('r', f); break;
-			case '\t': fputc('\\', f); fputc('t', f); break;
-			case ' ': fputc('\\', f); fputc(' ', f); break;
-			default:
-				fputc(*val, f);
-		}
-	}
-}
-
 static void export_attr(FILE *f, const char *cmd, const char *key, const char *val, const char *val2)
 {
 	if ((key == NULL) || (val == NULL))
 		return;
 	fprintf(f, "%s ", cmd);
-	tdx_fprint_escape(f, key);
+	tedax_fprint_escape(f, key);
 	fputc(' ', f);
-	tdx_fprint_escape(f, val);
+	tedax_fprint_escape(f, val);
 	if (val2 != NULL) {
 		fputc(' ', f);
-		tdx_fprint_escape(f, val2);
+		tedax_fprint_escape(f, val2);
 	}
 	fputc('\n', f);
 }
@@ -198,11 +180,11 @@ static void tdx_export_nets(FILE *f, csch_abstract_t *abs)
 				}
 				net_exported = 1;
 				fprintf(f, "conn ");
-				tdx_fprint_escape(f, netname);
+				tedax_fprint_escape(f, netname);
 				fputc(' ', f);
-				tdx_fprint_escape(f, refdes);
+				tedax_fprint_escape(f, refdes);
 				fputc(' ', f);
-				tdx_fprint_escape(f, s);
+				tedax_fprint_escape(f, s);
 				fputc('\n', f);
 			}
 		}
@@ -223,7 +205,7 @@ static int tdx_export_project_abst(const char *fn, const char *fmt, csch_abstrac
 
 	fprintf(f, "tEDAx v1\n");
 	fprintf(f, "begin netlist v1 ");
-	tdx_fprint_escape(f, "<TODO: name>");
+	tedax_fprint_escape(f, "<TODO: name>");
 	fprintf(f, "\n");
 
 	tdx_export_comps(f, abs);
