@@ -163,7 +163,10 @@ fgw_error_t csch_act_Popup(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 					}
 					else if (csch_obj_is_grp(obj)) {
 						csch_cgrp_t *grp = (csch_cgrp_t *)obj;
-						if (grp->srole != NULL) {
+						if (grp->extobj != NULL) {
+							tn = misc = "extobj";
+						}
+						else if (grp->srole != NULL) {
 							tn = ((csch_cgrp_t *)obj)->srole;
 							misc = "unknown-grp";
 						}
@@ -176,7 +179,12 @@ fgw_error_t csch_act_Popup(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 						}
 					}
 					else {
-						if (obj->parent->role == CSCH_ROLE_WIRE_NET) {
+						if (obj->parent->extobj != NULL) {
+							sprintf(wnname, "extobj-%s", csch_ctype_name(obj->type));
+							tn = wnname;
+							misc = "extobj";
+						}
+						else if (obj->parent->role == CSCH_ROLE_WIRE_NET) {
 							sprintf(wnname, "wire-net-%s", csch_ctype_name(obj->type));
 							tn = wnname;
 							misc = "wire-net";
