@@ -30,8 +30,8 @@
 #include <librnd/core/compat_misc.h>
 #include <librnd/core/error.h>
 
-#include <libnanojson/nanojson.c>
-#include <libnanojson/semantic.c>
+#include <libnanojson/nanojson.h>
+#include <libnanojson/semantic.h>
 
 #include <rnd_inclib/lib_easyeda/gendom.c>
 #include <rnd_inclib/lib_easyeda/gendom_json.c>
