@@ -93,6 +93,7 @@ typedef struct read_ctx_s {
 	int last_comp_rot;
 	unsigned last_comp_mir:1;
 	unsigned last_comp_embedded:1;
+	unsigned loading_emcomp:1;    /* set to 1 while loading embedded component */
 
 	unsigned silent:1;
 	unsigned no_ext_sym:1;        /* do not attempt to load external symbols from the geda lib */
@@ -334,9 +335,12 @@ static void attr_set_maybe_arr(csch_sheet_t *sheet, csch_cgrp_t *obj, int prio,
 {
 	csch_attrib_t *a = csch_attrib_get(&obj->attr, key);
 
-	if (a == NULL) {
-		/* first value -> create attrs */
+
+	if ((a == NULL) || (prio < a->prio)) {
+		/* first value or {}-overwrites[]-via-prio -> create attrs */
 		csch_cobj_attrib_set(sheet, obj, prio, key, val, source);
+		a = csch_attrib_get(&obj->attr, key);
+		a->prio = prio;
 		return;
 	}
 
@@ -380,7 +384,7 @@ static int place_text(read_ctx_t *ctx, csch_cgrp_t *parent, long x, long y, long
 			*sep = '\0';
 			sep++;
 			if (create_attr)
-				attr_set_maybe_arr(ctx->sheet, parent, CSCH_ATP_USER_DEFAULT, s, sep, geda_src(ctx));
+				attr_set_maybe_arr(ctx->sheet, parent, CSCH_ATP_USER_DEFAULT + ctx->loading_emcomp, s, sep, geda_src(ctx));
 			if (vis) {
 				text = (csch_text_t *)csch_alien_mktext(&ctx->alien, parent, x, y, penname);
 				y -= DEF_TERM_GRID;
@@ -442,6 +446,8 @@ static int place_text(read_ctx_t *ctx, csch_cgrp_t *parent, long x, long y, long
 					break;
 			}
 		}
+		if (text != NULL)
+			csch_text_update(ctx->alien.sheet, text, 1);
 	}
 
 
@@ -895,7 +901,7 @@ static csch_cgrp_t *load_sym(rnd_design_t *hidlib, const char *fn, csch_sheet_t
 
 /* Move over all attributes and properites from src sym to dst sym and remove
    src sym */
-static void last_comp_move_fields(read_ctx_t *ctx, csch_cgrp_t *dst, csch_cgrp_t *src)
+static void last_comp_move_fields_props(read_ctx_t *ctx, csch_cgrp_t *dst, csch_cgrp_t *src)
 {
 	double x, y;
 
@@ -908,8 +914,11 @@ static void last_comp_move_fields(read_ctx_t *ctx, csch_cgrp_t *dst, csch_cgrp_t
 	dst->mirx = ctx->last_comp_mir;
 	dst->x = rnd_round(x);
 	dst->y = rnd_round(y);
+}
 
-	/* move over all attributes: any src attrib fully rewrites dst attrib */
+/* move over all attributes and floaters: any src attrib fully rewrites dst attrib */
+static void last_comp_move_fields_attrs(read_ctx_t *ctx, csch_cgrp_t *dst, csch_cgrp_t *src)
+{
 	{
 		htsp_entry_t *e;
 		for(e = htsp_first(&src->attr); e != NULL; e = htsp_next(&src->attr, e)) {
@@ -932,9 +941,19 @@ static void last_comp_move_fields(read_ctx_t *ctx, csch_cgrp_t *dst, csch_cgrp_t
 			remove_orig_attr_by_text(ctx, dst, t->text);
 
 			newt = csch_text_dup(ctx->sheet, dst, t, 0, 0);
-			newt->spec1.x -= dst->x;
-			newt->spec1.y -= dst->y;
+
+			newt->spec1.x = t->spec1.x;
+			newt->spec1.y = t->spec1.y;
+			csch_cgrp_vinverse_xform(dst, &newt->spec1.x, &newt->spec1.y, NULL);
+
+			newt->spec_rot -= dst->spec_rot;
+			newt->spec_mirx = t->spec_mirx ^ dst->mirx;
+			newt->spec_miry = t->spec_miry ^ dst->miry;
+
 			csch_text_update(ctx->sheet, newt, 1);
+
+			/* rnd_trace(" TXT: spec=%ld;%ld inst=%ld;%ld\n", newt->spec1.x, newt->spec1.y, newt->inst1.x, newt->inst1.y); */
+
 		}
 	}
 
@@ -968,13 +987,19 @@ static void flush_last_comp(read_ctx_t *ctx)
 
 			if (ds->grp != NULL) {
 				csch_cgrp_t *newo = (csch_cgrp_t *)csch_cobj_dup(ctx->sheet, &ctx->sheet->direct, &ds->grp->hdr, 0, 0);
+
+				last_comp_move_fields_props(ctx, newo, ctx->last_comp);
+
+
+				if (newo->mirx)
+					newo->spec_rot = -newo->spec_rot;
+
+TODO("remove this dead code after some testing:");
+#if 0
+				/* offset coming from the symbol; this used to be bbox bottom left */
 				rnd_coord_t ox, oy;
+				ox = oy = 0;
 
-				last_comp_move_fields(ctx, newo, ctx->last_comp);
-
-/* This breaks. We shouldn't ever use the bbox, but symbol's 0;0 */
-				ox = ds->grp->hdr.bbox.x1 * 0;
-				oy = ds->grp->hdr.bbox.y1;
 				if ((ox != 0) || (oy != 0)) {
 					if (newo->spec_rot != 0) {
 						double rad = -newo->spec_rot / RND_RAD_TO_DEG;
@@ -985,7 +1010,10 @@ static void flush_last_comp(read_ctx_t *ctx)
 					newo->x -= ox;
 					newo->y -= oy;
 				}
+#endif
 
+				csch_cgrp_update(ctx->alien.sheet, newo, 1); /* make sure transformations are available for floater text placement */
+				last_comp_move_fields_attrs(ctx, newo, ctx->last_comp);
 			}
 			else {
 				error(ctx, ("Failed to load library symbol called '%s'\n", ctx->last_comp_name));
@@ -1100,6 +1128,7 @@ static int read_emcomp(read_ctx_t *ctx, csch_cgrp_t *parent)
 	READ_NL(ctx); /* of the opening line */
 
 	ctx->last_comp_embedded = 1;
+	ctx->loading_emcomp = 1;
 	grp->x = grp->y = 0;
 
 	for(;;) {
@@ -1115,6 +1144,7 @@ static int read_emcomp(read_ctx_t *ctx, csch_cgrp_t *parent)
 			return -1;
 		}
 	}
+	ctx->loading_emcomp = 0;
 
 	READ_NL(ctx); /* of the closing line */
 	flush_last_comp(ctx);
