@@ -1272,6 +1272,8 @@ void test_parse_ev(lht_parse_t *ctx, lht_event_t ev, lht_node_type_t nt, const c
 			tp->have = CSCH_IOTYP_GROUP;
 		else if ((nt == LHT_HASH) && (strncmp(name, "coraleda-project-v", 18) == 0))
 			tp->have = CSCH_IOTYP_PROJECT;
+		else if ((nt == LHT_LIST) && (strncmp(name, "sch-rnd-attbl-v", 15) == 0))
+			tp->have = CSCH_IOTYP_ATTBL;
 		else
 			tp->have = 0;
 
