@@ -72,7 +72,7 @@ static int attr_cmp(const void *v1, const void *v2)
 	return strcmp((*a1)->key, (*a2)->key);
 }
 
-static void lht_print_str(FILE *f, const char *s)
+void lht_print_str(FILE *f, const char *s)
 {
 	if (s == NULL) {
 		fprintf(f, "{}");
@@ -621,19 +621,25 @@ int io_lihata_save_buffer(const char *fn, const char *fmt, const csch_sheet_t *d
 
 int io_lihata_save_grp(const char *fn, const char *fmt, const csch_cgrp_t *src, int inhibit_uuid)
 {
-	int r = 0;
+	int r = 0, do_close = 0;
 	write_ctx_t ctx;
 
 	ctx.sheet = src->hdr.sheet;
-	ctx.f = rnd_fopen((rnd_design_t *)&ctx.sheet->hidlib, fn, "w");
-	if (ctx.f == NULL)
-		return -1;
+	if (strcmp(fn, "/dev/stdout") != 0) {
+		ctx.f = rnd_fopen((rnd_design_t *)&ctx.sheet->hidlib, fn, "w");
+		if (ctx.f == NULL)
+			return -1;
+		do_close = 1;
+	}
+	else
+		ctx.f = stdout;
 
 	fprintf(ctx.f, "ha:cschem-group-v1 {\n");
 	r |= lht_save_group(&ctx, 1, src, "group", 1, inhibit_uuid);
 	fprintf(ctx.f, "}\n");
 
-	fclose(ctx.f);
+	if (do_close)
+		fclose(ctx.f);
 	return r;
 }
 
