@@ -99,7 +99,7 @@ void sch_trgt_ctx_init(sch_trgt_ctx_t *ctx, const rnd_conflist_t *whitelist, con
 	if (ctx->has_black) {
 		htss_init(&ctx->black, strhash, strkeyeq);
 		rnd_conf_loop_list_str(blacklist, item_li, item_str, idx) {
-			htss_set(&ctx->white, (char *)item_str, dflt);
+			htss_set(&ctx->black, (char *)item_str, dflt);
 		}
 	}
 }
@@ -137,7 +137,7 @@ void sch_trgt_export_attrs(sch_trgt_ctx_t *ctx, csch_ahdr_t *obj)
 		/* black list: remove export name even if it was set by some other plugin beforehand */
 		if (ctx->has_black) {
 			const char *wh = htss_get(&ctx->black, e->key);
-			if (wh != dflt) {
+			if (wh == dflt) {
 				if (a->export_name != NULL) {
 					free(a->export_name);
 					a->export_name = NULL;
