@@ -54,6 +54,8 @@ void pcb_qry_init(pcb_qry_exec_t *ctx, csch_sheet_t *sheet, pcb_qry_node_t *root
 	ctx->all.type = PCBQ_VT_LST;
 	if (bufno == -1)
 		pcb_qry_list_all_sheet(&ctx->all, sheet, CSCH_CMASK_ANY);
+	else if (bufno == -2)
+		pcb_qry_list_all_sheet_indirect(&ctx->all, sheet, CSCH_CMASK_ANY);
 	else
 		pcb_qry_list_all_sheet(&ctx->all, sch_rnd_buffer[bufno], CSCH_CMASK_ANY);
 
