@@ -1,7 +1,7 @@
 /*
  *                            COPYRIGHT
  *
- *  cschem - modular/flexible schematics editor - GUI
+ *  sch-rnd - modular/flexible schematics editor - GUI - pen dialog
  *  Copyright (C) 2022 Tibor 'Igor2' Palinkas
  *
  *  (Supported by NLnet NGI0 PET Fund in 2022)
@@ -58,7 +58,11 @@
 #include <sch-rnd/crosshair.h>
 #include <sch-rnd/dad.h>
 
-#include "timed_chg.h"
+
+/* This doesn't make a plugin dep as only inlines and macros and structs are used */
+#include <sch-rnd/conf_core.h>
+#define RND_TIMED_CHG_TIMEOUT conf_core.editor.edit_time
+#include <librnd/plugins/lib_hid_common/timed_chg.h>
 
 typedef struct pendlg_ctx_s pendlg_ctx_t;
 
@@ -73,7 +77,7 @@ struct pendlg_ctx_s {
 
 	/* timed changes */
 	struct {
-		csch_timed_chg_t hdr;
+		rnd_timed_chg_t hdr;
 
 		csch_cpen_t *pen; /* pen to apply these changes to */
 
@@ -84,7 +88,7 @@ struct pendlg_ctx_s {
 	} font;
 
 	struct {
-		csch_timed_chg_t hdr;
+		rnd_timed_chg_t hdr;
 
 		csch_cpen_t *pen; /* pen to apply these changes to */
 
@@ -105,8 +109,8 @@ static void pens_map(pendlg_ctx_t *ctx);
 /* finalize all pending operations */
 static void pendlg_finalize(pendlg_ctx_t *ctx)
 {
-	csch_timed_chg_finalize(&ctx->font.hdr);
-	csch_timed_chg_finalize(&ctx->tip.hdr);
+	rnd_timed_chg_finalize(&ctx->font.hdr);
+	rnd_timed_chg_finalize(&ctx->tip.hdr);
 }
 
 static void pendlg_close_cb(void *caller_data, rnd_hid_attr_ev_t ev)
@@ -358,7 +362,7 @@ static void set_pen_name_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_
 
 	ctx->tip.pen = pen;
 	ctx->tip.name = 1;
-	csch_timed_chg_schedule(&ctx->tip.hdr);
+	rnd_timed_chg_schedule(&ctx->tip.hdr);
 }
 
 static void set_pen_shape_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr)
@@ -371,7 +375,7 @@ static void set_pen_shape_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute
 
 	ctx->tip.pen = pen;
 	ctx->tip.shape = 1;
-	csch_timed_chg_schedule(&ctx->tip.hdr);
+	rnd_timed_chg_schedule(&ctx->tip.hdr);
 }
 
 static void set_pen_size_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr)
@@ -384,7 +388,7 @@ static void set_pen_size_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_
 
 	ctx->tip.pen = pen;
 	ctx->tip.size = 1;
-	csch_timed_chg_schedule(&ctx->tip.hdr);
+	rnd_timed_chg_schedule(&ctx->tip.hdr);
 }
 
 static void set_pen_color_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr)
@@ -397,7 +401,7 @@ static void set_pen_color_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute
 
 	ctx->tip.pen = pen;
 	ctx->tip.color = 1;
-	csch_timed_chg_schedule(&ctx->tip.hdr);
+	rnd_timed_chg_schedule(&ctx->tip.hdr);
 
 }
 
@@ -440,7 +444,7 @@ static void set_pen_fontheight_cb(void *hid_ctx, void *caller_data, rnd_hid_attr
 
 	ctx->font.pen = pen;
 	ctx->font.height = 1;
-	csch_timed_chg_schedule(&ctx->font.hdr);
+	rnd_timed_chg_schedule(&ctx->font.hdr);
 }
 
 static void set_pen_fontfamily_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr)
@@ -453,7 +457,7 @@ static void set_pen_fontfamily_cb(void *hid_ctx, void *caller_data, rnd_hid_attr
 
 	ctx->font.pen = pen;
 	ctx->font.family = 1;
-	csch_timed_chg_schedule(&ctx->font.hdr);
+	rnd_timed_chg_schedule(&ctx->font.hdr);
 }
 
 static void set_pen_fontstyle_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr)
@@ -466,7 +470,7 @@ static void set_pen_fontstyle_cb(void *hid_ctx, void *caller_data, rnd_hid_attri
 
 	ctx->font.pen = pen;
 	ctx->font.style = 1;
-	csch_timed_chg_schedule(&ctx->font.hdr);
+	rnd_timed_chg_schedule(&ctx->font.hdr);
 }
 
 
@@ -509,8 +513,8 @@ const char *sch_rnd_pen_dlg(csch_sheet_t *sheet, csch_cgrp_t *grp, const char *p
 	htsp_init(&ctx->pens, strhash, strkeyeq);
 	pens_map(ctx);
 
-	csch_timed_chg_init(&ctx->font.hdr, set_pen_font_timed, ctx);
-	csch_timed_chg_init(&ctx->tip.hdr,  set_pen_tip_timed, ctx);
+	rnd_timed_chg_init(&ctx->font.hdr, set_pen_font_timed, ctx);
+	rnd_timed_chg_init(&ctx->tip.hdr,  set_pen_tip_timed, ctx);
 
 	if (!modal)
 		gdl_append(&pendlgs, ctx, link);
@@ -588,8 +592,8 @@ const char *sch_rnd_pen_dlg(csch_sheet_t *sheet, csch_cgrp_t *grp, const char *p
 						RND_DAD_CHANGE_CB(ctx->dlg, set_pen_fontstyle_cb);
 				RND_DAD_END(ctx->dlg);
 
-				CSCH_DAD_TIMING(ctx->dlg, &ctx->font.hdr, "font");
-				CSCH_DAD_TIMING(ctx->dlg, &ctx->tip.hdr, "tip");
+				RND_DAD_TIMING(ctx->dlg, &ctx->font.hdr, "font");
+				RND_DAD_TIMING(ctx->dlg, &ctx->tip.hdr, "tip");
 
 			RND_DAD_END(ctx->dlg);
 		RND_DAD_END(ctx->dlg);
@@ -601,8 +605,8 @@ const char *sch_rnd_pen_dlg(csch_sheet_t *sheet, csch_cgrp_t *grp, const char *p
 	RND_DAD_DEFSIZE(ctx->dlg, 200, 300);
 	RND_DAD_NEW("PenDialog", ctx->dlg, "Pen edit", ctx, modal, pendlg_close_cb); /* type=local */
 
-	csch_timed_chg_timing_init(&ctx->font.hdr, ctx->dlg_hid_ctx);
-	csch_timed_chg_timing_init(&ctx->tip.hdr, ctx->dlg_hid_ctx);
+	rnd_timed_chg_timing_init(&ctx->font.hdr, ctx->dlg_hid_ctx);
+	rnd_timed_chg_timing_init(&ctx->tip.hdr, ctx->dlg_hid_ctx);
 
 	pens2dlg(ctx);
 	if (pen_name != NULL) {
