@@ -56,6 +56,7 @@
 #include "dlg_library.h"
 #include "dlg_infobar.c"
 #include "dlg_view.h"
+#include "dlg_viewport.h"
 #include "dlg_project.h"
 #include "quick_attr.h"
 
@@ -79,6 +80,7 @@ static rnd_action_t sch_dialogs_action_list[] = {
 	{"LibraryDialog", csch_act_LibraryDialog, csch_acth_LibraryDialog, csch_acts_LibraryDialog},
 	{"InfoBarFileChanged", csch_act_InfoBarFileChanged, csch_acth_InfoBarFileChanged, csch_acts_InfoBarFileChanged},
 	{"ViewDialog", csch_act_ViewDialog, csch_acth_ViewDialog, csch_acts_ViewDialog},
+	{"ViewPortDialog", csch_act_ViewPortDialog, csch_acth_ViewPortDialog, csch_acts_ViewPortDialog},
 	{"ProjectDialog", csch_act_ProjectDialog, csch_acth_ProjectDialog, csch_acts_ProjectDialog},
 	{"About", csch_act_About, csch_acth_About, csch_acts_About},
 	{"StanceDialog", csch_act_StanceDialog, csch_acth_StanceDialog, csch_acts_StanceDialog},
@@ -103,6 +105,7 @@ static void csch_dlg_ev_preunload(rnd_design_t *hidlib, void *user_data, int arg
 	csch_dlg_library_preunload(sheet);
 	csch_dlg_tree_chg_sheet(sheet);
 	csch_dlg_cond_preunload(sheet);
+	csch_dlg_viewport_preunload(sheet);
 }
 
 static void csch_dlg_ev_sheet_edit(rnd_design_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
@@ -110,6 +113,7 @@ static void csch_dlg_ev_sheet_edit(rnd_design_t *hidlib, void *user_data, int ar
 	csch_sheet_t *sheet = (csch_sheet_t *)hidlib;
 	csch_dlg_tree_edit(sheet);
 	csch_dlg_attr_edit(sheet);
+	csch_dlg_viewport_edit(sheet);
 }
 
 static void csch_dlg_ev_obj_attr_edit(rnd_design_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
@@ -160,6 +164,7 @@ void pplg_uninit_sch_dialogs(void)
 	csch_dlg_cond_uninit();
 	csch_dlg_library_uninit();
 	sch_rnd_attr_quick_uninit();
+	csch_dlg_viewport_uninit();
 	rnd_dlg_pref_uninit();
 	rnd_conf_plug_unreg("plugins/dialogs/", adialogs_conf_internal, sch_dialogs_cookie);
 
