@@ -346,7 +346,7 @@ static int se_ngspice_exec(csch_project_t *prj, sch_sim_setup_t *setup)
 			case SCH_SIMAN_DC_DISTO_DEC: fprintf(fcmd, "disto dec %d %s %s\n", an->numpt, an->start, an->stop); break;
 			case SCH_SIMAN_DC_DISTO_OCT: fprintf(fcmd, "disto oct %d %s %s\n", an->numpt, an->start, an->stop); break;
 			case SCH_SIMAN_DC_DISTO_LIN: fprintf(fcmd, "disto lin %d %s %s\n", an->numpt, an->start, an->stop); break;
-			case SCH_SIMAN_DC_NOISE_DEC: fprintf(fcmd, "noise v(%s) %s dec %d %s %s\n", an->port2, an->port1, an->numpt, an->start, an->stop); break;
+			case SCH_SIMAN_DC_NOISE_DEC: fprintf(fcmd, "noise v(%s) %s dec %d %s %s\n", an->port2[0], an->port1[0], an->numpt, an->start, an->stop); break;
 
 			case SCH_SIMAN_PREVIOUS: break; /* do not print anything */
 
