@@ -61,8 +61,10 @@ csch_lib_type_t symlib_fs_file_type(rnd_design_t *hl, const char *fn)
 	f = rnd_fopen(hl, fn, "r");
 	if (f == NULL)
 		return CSCH_SLIB_invalid;
-	fread(head, 2, 1, f);
-	if ((head[0] == '#') && (head[1] == '!')) {
+
+	res = fread(head, 2, 1, f);
+
+	if ((res < 1) || ((head[0] == '#') && (head[1] == '!'))) {
 		fclose(f);
 		return CSCH_SLIB_PARAMETRIC;
 	}
