@@ -552,7 +552,7 @@ static void shared_port_connect(spicelib_ctx_t *ctx, csch_abstract_t *abst)
 				csch_aport_t *port = e->value.ports.array[n];
 				if ((port->conn.net == NULL) || (port->conn.net != net)) {
 					if (csch_compile_connect_net_to(&net, &port->hdr, 1) != 0)
-						rnd_message(RND_MSG_ERROR, "target_spice: shared port %s-%s failed to connect to %s\n", port->parent->name, port->name, net->name);
+						rnd_message(RND_MSG_ERROR, "target_spice: shared port %s-%s failed to connect to %s\n", APORT_PARENT_NAME(port), port->name, net->name);
 				}
 			}
 		}
@@ -673,7 +673,7 @@ static void bridge_insert(spicelib_ctx_t *ctx, csch_abstract_t *abst, csch_aport
 					err = 1;
 			}
 			if (err)
-				rnd_message(RND_MSG_ERROR, "Invalid spice/bridge/dir on component %s port %s: '%s'; should be n1p2 or p1n2\n", port->parent->name, port->name, dir);
+				rnd_message(RND_MSG_ERROR, "Invalid spice/bridge/dir on component %s port %s: '%s'; should be n1p2 or p1n2\n", APORT_PARENT_NAME(port), port->name, dir);
 		}
 	}
 
