@@ -676,14 +676,19 @@ void sch_rnd_draw_sheet(csch_sheet_t *sheet, rnd_hid_gc_t gc, const rnd_hid_expo
 		sch_rnd_draw_sheet_graphical(sheet, gc, region, xform_caller);
 }
 
-
+rnd_box_t sch_rnd_last_main_expose_region;
 void sch_rnd_expose_main(rnd_hid_t *hid, const rnd_hid_expose_ctx_t *region, rnd_xform_t *xform_caller)
 {
 	rnd_hid_gc_t gc;
 	int want_layer;
 	csch_sheet_t *sheet = (csch_sheet_t *)region->design;
 	rnd_hid_t *save = rnd_render;
-	
+
+	sch_rnd_last_main_expose_region.X1 = region->view.X1;
+	sch_rnd_last_main_expose_region.Y1 = region->view.Y1;
+	sch_rnd_last_main_expose_region.X2 = region->view.X2;
+	sch_rnd_last_main_expose_region.Y2 = region->view.Y2;
+
 	if ((rnd_render != NULL) && (!rnd_render->override_render))
 		rnd_render = hid;
 
@@ -754,11 +759,13 @@ void sch_rnd_box_redraw_ev(rnd_design_t *hidlib, void *user_data, int argc, rnd_
 		return;
 
 	assert(argv[1].type == RND_EVARG_PTR);
-	if (rnd_render->gui && (rnd_render->invalidate_lr != NULL))
+	if (rnd_render->gui && (rnd_render->invalidate_lr != NULL)) {
+		rnd_hid_notify_crosshair_change(hidlib, 0);
 		rnd_render->invalidate_lr(rnd_render, C2P(box->x1), C2P(box->x2), C2P(box->y1), C2P(box->y2));
+		rnd_hid_notify_crosshair_change(hidlib, 1);
+	}
 
 	/* rnd_trace("LR: %rc %rc - %rc %rc\n", box->x1, box->y1, box->x2, box->y2); */
-
 }
 
 void sch_rnd_draw_init2(void)
