@@ -1,7 +1,7 @@
 /*
  *                            COPYRIGHT
  *
- *  cschem - modular/flexible schematics editor - sch-rnd (executable)
+ *  sch-rnd - modular/flexible schematics editor - sch-rnd (executable)
  *  Copyright (C) 2022 Tibor 'Igor2' Palinkas
  *
  *  (Supported by NLnet NGI0 PET Fund in 2022)
@@ -73,7 +73,14 @@ static csch_project_t *sch_rnd_multi_load_project_(const char *project_fn)
 	if (prj == NULL) {
 		char *pfn = rnd_strdup(project_fn);
 		prj = csch_load_project_by_sheet_name(pfn, 0, rnd_conf.rc.quiet);
-		htsp_set(&rnd_projects, pfn, prj);
+		if (prj->hdr.loadname != NULL) {
+			htsp_set(&rnd_projects, prj->hdr.loadname, prj);
+			free(pfn);
+		}
+		else {
+			TODO("memleak: this leaks pfn; happens when loading a sheet without a project file");
+			htsp_set(&rnd_projects, pfn, prj);
+		}
 	}
 	return prj;
 }
@@ -320,6 +327,21 @@ csch_sheet_t *sch_rnd_multi_load(const char *fn, const char *fmt, int *is_projec
 	return sheet;
 }
 
+csch_sheet_t *sch_rnd_app_load_sheet(csch_project_t *proj, const char *path)
+{
+	int is_project;
+	csch_sheet_t *res;
+	rnd_design_t *last;
+
+	last = rnd_multi_switch_to(NULL); /* empty conf so we can overwrite */
+	res = sch_rnd_multi_load_(path, NULL, proj->hdr.loadname, &is_project, NULL, NULL);
+	res->stype = CSCH_SHTY_EXTERNAL;
+	rnd_multi_switch_to_(last); /* activate the original */
+
+	return res;
+}
+
+
 static csch_sheet_t *sch_rnd_multi_new_empty_(csch_project_t *prj, const char *fn)
 {
 	csch_sheet_t *sheet;
@@ -341,7 +363,26 @@ static csch_sheet_t *sch_rnd_multi_new_empty_(csch_project_t *prj, const char *f
 	}
 
 	sheet = sch_rnd_sheet_new(prj);
+
+	/* set filename before postprocessing the sheet so that libs dependeing
+	   on $(rc.path.design) already have it filled in */
+	if (fn == NULL)
+		fn = "<none>";
+
+	if (!rnd_is_dir(NULL, fn)) {
+		/* If we failed to load a file with a given file name and created an
+		   empty sheet instead, remember the file name for the new sheet so
+		   {f s} saves using that name specified originally */
+		if (sheet != NULL) {
+			sheet->hidlib.loadname = rnd_strdup(fn);
+			sheet->hidlib.fullpath = rnd_strdup(fn);
+		}
+	}
+	else
+		rnd_message(RND_MSG_ERROR, "Supplied sheet name '%s' is a directory, can't save sheet by that name.\n", fn);
+
 	rnd_conf_multi_post_new_design(&ncs,&sheet->hidlib);
+
 	if (sheet != NULL) {
 		rnd_multi_load_prj_for_dsg(&sheet->hidlib);
 		rnd_conf_state_new_design(&sheet->hidlib);
@@ -357,18 +398,6 @@ static csch_sheet_t *sch_rnd_multi_new_empty_(csch_project_t *prj, const char *f
 /*		sch_rnd_prj_free(prj);*/
 	}
 
-	if (fn == NULL)
-		fn = "<none>";
-
-	if (!rnd_is_dir(NULL, fn)) {
-		/* If we failed to load a file with a given file name and created an
-		   empty sheet instead, remember the file name for the new sheet so
-		   {f s} saves using that name specified originally */
-		sheet->hidlib.loadname = rnd_strdup(fn);
-		sheet->hidlib.fullpath = rnd_strdup(fn);
-	}
-	else
-		rnd_message(RND_MSG_ERROR, "Supplied sheet name '%s' is a directory, can't save sheet by that name.\n", fn);
 
 	rnd_conf_state_save(sheet->hidlib.saved_rnd_conf);
 
@@ -380,9 +409,9 @@ csch_sheet_t *sch_rnd_multi_new_empty(const char *fn)
 	return sch_rnd_multi_new_empty_(NULL, fn);
 }
 
-csch_sheet_t *sch_rnd_multi_new_empty_in_prj(csch_project_t *prj)
+csch_sheet_t *sch_rnd_multi_new_empty_in_prj(csch_project_t *prj, const char *path)
 {
-	return sch_rnd_multi_new_empty_(prj, NULL);
+	return sch_rnd_multi_new_empty_(prj, path);
 }
 
 
@@ -420,9 +449,22 @@ void sch_rnd_multi_uninit(void)
 void sch_rnd_sheet_free_all(void)
 {
 	rnd_design_t *curr, *next;
+	htsp_entry_t *e;
+
+	/* free all projects (will free all sheets too) */
+	while((e = htsp_first(&rnd_projects)) != NULL) {
+		csch_project_t *prj = e->value;
+
+		htsp_delentry(&rnd_projects, e);
+		csch_project_free(prj);
+	}
+
+	/* just in case anything left outside of known projects */
 	for(curr = gdl_first(&rnd_designs); curr != NULL; curr = next) {
 		next = gdl_next(&rnd_designs, curr);
-		gdl_remove(&rnd_designs, curr, link);
-		csch_sheet_free((csch_sheet_t *)curr);
+
+		csch_sheet_uninit((csch_sheet_t *)curr);
+		rnd_conf_state_del_design(curr); /* also removes curr from rnd_designs */
+		free(curr);
 	}
 }
