@@ -1,7 +1,7 @@
 /*
  *                            COPYRIGHT
  *
- *  cschem - modular/flexible schematics editor - sch-rnd (executable)
+ *  sch-rnd - modular/flexible schematics editor - sch-rnd (executable)
  *  Copyright (C) 2022 Tibor 'Igor2' Palinkas
  *
  *  (Supported by NLnet NGI0 PET Fund in 2022)
@@ -95,23 +95,27 @@ void sch_rnd_sheet_warn_size(csch_sheet_t *sheet, csch_coord_t x1, csch_coord_t
 	warn_size(sheet, x2); warn_size(sheet, y2);
 }
 
+void sch_rnd_sheet_recalc_bbox(csch_sheet_t *sheet)
+{
+		rnd_coord_t min_x = sheet_attr_crd(sheet, "drawing_min_width", 0);
+		rnd_coord_t min_y = sheet_attr_crd(sheet, "drawing_min_height", 0);
+
+	csch_sheet_bbox_update(sheet);
+
+	sheet->hidlib.dwg.X1 = C2P(sheet->bbox.x1);
+	sheet->hidlib.dwg.Y1 = C2P(sheet->bbox.y1);
+	sheet->hidlib.dwg.X2 = C2P(RND_MAX(min_x, sheet->bbox.x2));
+	sheet->hidlib.dwg.Y2 = C2P(RND_MAX(min_y, sheet->bbox.y2));
+
+	sch_rnd_sheet_warn_size(sheet, sheet->bbox.x1, sheet->bbox.y1, RND_MAX(min_x, sheet->bbox.x2), RND_MAX(min_y, sheet->bbox.y2));
+}
+
 void sch_rnd_sheet_postproc(csch_sheet_t *sheet)
 {
 	sheet->hidlib.grid = rnd_conf.editor.grid;
 
-	if (!sheet->non_graphical) {
-		rnd_coord_t min_x = sheet_attr_crd(sheet, "drawing_min_width", 0);
-		rnd_coord_t min_y = sheet_attr_crd(sheet, "drawing_min_height", 0);
-
-		csch_sheet_bbox_update(sheet);
-
-		sheet->hidlib.dwg.X1 = C2P(sheet->bbox.x1);
-		sheet->hidlib.dwg.Y1 = C2P(sheet->bbox.y1);
-		sheet->hidlib.dwg.X2 = C2P(RND_MAX(min_x, sheet->bbox.x2));
-		sheet->hidlib.dwg.Y2 = C2P(RND_MAX(min_y, sheet->bbox.y2));
-
-		sch_rnd_sheet_warn_size(sheet, sheet->bbox.x1, sheet->bbox.y1, RND_MAX(min_x, sheet->bbox.x2), RND_MAX(min_y, sheet->bbox.y2));
-	}
+	if (!sheet->non_graphical)
+		sch_rnd_sheet_recalc_bbox(sheet);
 
 	if (sheet->hidlib.fullpath != NULL) {
 		sheet->design_dir = rnd_dirname(sheet->hidlib.fullpath);
@@ -127,6 +131,7 @@ void sch_rnd_sheet_postproc(csch_sheet_t *sheet)
 		/* This works from load only because the conf state is already set up for
 		   the new sheet, even tho librnd's current sheet is not yet set */
 		csch_lib_add_all(sheet, csch_lib_get_master("symbol", 1), &conf_core.rc.library_search_paths, 0);
+		csch_lib_add_all(sheet, csch_lib_get_master("hlibrary", 1), &conf_core.rc.hlibrary_search_paths, 0);
 	}
 
 	if (sheet->is_symbol)
